pub struct MiddlewareChain { /* private fields */ }Expand description
Builds and executes the middleware chain
The chain is built from the outside-in:
- Global middleware (first to run)
- Route group middleware
- Route-level middleware
- The actual route handler (innermost)
Implementations
Sourceimpl MiddlewareChain
impl MiddlewareChain
Sourcepub fn push(&mut self, middleware: BoxedMiddleware)
pub fn push(&mut self, middleware: BoxedMiddleware)
Add middleware to the chain
Middleware are executed in the order they are added.
Sourcepub fn extend(&mut self, middleware: impl IntoIterator<Item = BoxedMiddleware>)
pub fn extend(&mut self, middleware: impl IntoIterator<Item = BoxedMiddleware>)
Add multiple middleware to the chain
Sourcepub async fn execute(
self,
request: Request,
handler: Arc<BoxedHandler>,
) -> Response
pub async fn execute( self, request: Request, handler: Arc<BoxedHandler>, ) -> Response
Execute the middleware chain with the given request and final handler
The chain is executed from outside-in:
- First middleware added runs first
- Each middleware can call
next(request)to continue the chain - The final handler is called at the end of the chain