Framework-wide error types
Provides a unified error type that can be used throughout the framework and automatically converts to appropriate HTTP responses.
Enums
- Framework
Error - Framework-wide error type
Framework-wide error types
Provides a unified error type that can be used throughout the framework and automatically converts to appropriate HTTP responses.