Module http
Source pub use cookie::parse_cookies;pub use cookie::Cookie;pub use cookie::CookieOptions;pub use cookie::SameSite;
- cookie
- Cookie handling for Kit framework
- HttpResponse
- HTTP Response builder providing Laravel-like response creation
- ParamError
- Error type for missing route parameters
- Redirect
- HTTP Redirect response builder
- RedirectRouteBuilder
- Builder for redirects to named routes with parameters
- Request
- HTTP Request wrapper providing Laravel-like access to request data
- RequestParts
- Request parts after body has been separated
- FormRequest
- Trait for validated form/JSON request data
- FromParam
- Trait for types that can be extracted from a single path parameter
- FromRequest
- Trait for types that can be extracted from an HTTP request
- ResponseExt
- Extension trait for Response to enable method chaining on macros
- collect_body
- Collect the full body from an Incoming stream
- json
- Create a JSON response from a serde_json::Value
- parse_form
- Parse bytes as form-urlencoded into the target type
- parse_json
- Parse bytes as JSON into the target type
- text
- Create a text response
- Response
- Response type alias - allows using
? operator for early returns