pub struct GroupDef { /* private fields */ }Expand description
Implementations
Sourceimpl GroupDef
impl GroupDef
Sourcepub fn route<H, Fut>(self, route: RouteDefBuilder<H>) -> Self
pub fn route<H, Fut>(self, route: RouteDefBuilder<H>) -> Self
Add a route to this group
Sourcepub fn middleware<M: Middleware + 'static>(self, middleware: M) -> Self
pub fn middleware<M: Middleware + 'static>(self, middleware: M) -> Self
Sourcepub fn register(self, router: Router) -> Router
pub fn register(self, router: Router) -> Router
Register all routes in this group with the router
This prepends the group prefix to each route path and applies group middleware to all routes.
Path Combination
- If route path is “/” (root), the full path is just the group prefix
- Otherwise, prefix and route path are concatenated